@@ -16,11 +16,11 @@ intltoolize -c -f
 #gettextize -c -f
 
 # Scan configure.ac and copy the necessary macros into aclocal.m4.
-aclocal
+#aclocal
 
 # Generate Makefile.in from Makefile.am (and copy necessary support
 # files, because of -ac).
-automake -ac
+#automake -ac
 
 # This step is not normally necessary, but documented here for your
 # convenience. The files listed below need to be present to stop
@@ -29,9 +29,11 @@ automake -ac
 # You also should consider maintaining these files separately once
 # you release your project into the wild.
 #
-touch NEWS README AUTHORS ChangeLog
+#touch NEWS README AUTHORS ChangeLog
 
 # Run autoconf (will create the 'configure'-script).
-autoconf
+#autoconf
+
+autoreconf -i -m
 
 echo 'Ready to go (run configure)'
