@@ -1,4 +1,4 @@
 run-standalone.sh valgrind -v --track-fds=yes --track-origins=yes \
 --log-file=memcheck-mysocials-log-`date +%F-%H-%M-%S`.txt \
 --num-callers=150 --leak-check=full --show-reachable=yes \
---trace-children=yes mysocials
+--trace-children=yes mysocials 2>memcheck-mysocials-err-`date +%F-%H-%M-%S`.txt
