@@ -384,6 +384,7 @@ xmlDocPtr DB_GET_FRIENDS(xmlDocPtr request)
     xmlDocPtr fr_resp = xmlParseDoc(BAD_CAST "<Params><array name=\"contacts\"/></Params>");
     xmlNodePtr fr_resp_root = xmlDocGetRootElement(fr_resp);
     xmlNodePtr fr_resp_node = fr_resp_root->children;
+    xmlNodePtr node_set;
 
     gint fr_from = 0;
     gint fr_to = 0;
@@ -438,10 +439,18 @@ xmlDocPtr DB_GET_FRIENDS(xmlDocPtr request)
 
         /** filter if null or empty then no filter **/
         str = xmlGetProp(node_set, BAD_CAST "Filter");
-        if (str != NULL && strlen((char*)str) > 0) {
-            friends = search_contacts((const gchar*) str);  
-            is_filter_req = TRUE;
-            xmlSetProp(fr_resp_node, BAD_CAST "Filter", BAD_CAST str);
+        if (str != NULL) {
+            if (strlen((char*)str) > 0) {
+                friends = search_contacts((const gchar*) str);  
+                is_filter_req = TRUE;
+                xmlSetProp(fr_resp_node, BAD_CAST "Filter", BAD_CAST str);
+            } else {
+                db_resp = xmlParseDoc(BAD_CAST db_message);
+                db_resp = db_generate_message(db_resp,  ERROR_MESSAGE,
+                                              DB_ERROR_SEARCH_FRIENDS_TEXT,
+                                              DB_ERROR_SEARCH_FRIENDS_CODE);
+                return db_resp;             
+            }
         } // if (str) > 0
         xmlFree(str);
 
@@ -466,8 +475,8 @@ xmlDocPtr DB_GET_FRIENDS(xmlDocPtr request)
     if (friends == NULL) {
         db_resp = xmlParseDoc(BAD_CAST db_message);
         db_resp = db_generate_message(db_resp,  ERROR_MESSAGE,
-                                                DB_GET_ERROR_FRIENDS_TEXT,
-                                                DB_GET_ERROR_FRIENDS_CODE);
+                                                DB_ERROR_SEARCH_FRIENDS_TEXT,
+                                                DB_ERROR_SEARCH_FRIENDS_CODE);
         return db_resp;
     }
     
@@ -477,8 +486,8 @@ xmlDocPtr DB_GET_FRIENDS(xmlDocPtr request)
     xmlNodePtr friends_root = xmlDocGetRootElement(friends);
 
     xmlNodePtr friends_nodes = friends_root->children;
-    friends_root->children = NULL;
-    
+    friends_root->children = NULL;      
+
     while (friends_nodes != NULL) {
         xmlNodePtr tmpNode = friends_nodes->next;
         xmlUnlinkNode(friends_nodes);            
@@ -486,6 +495,7 @@ xmlDocPtr DB_GET_FRIENDS(xmlDocPtr request)
         friends_nodes = tmpNode;
     }
 
+ 
     xmlFreeDoc(friends);
 
         
@@ -493,8 +503,8 @@ xmlDocPtr DB_GET_FRIENDS(xmlDocPtr request)
                                                    CLASS_FRIENDS, GET_FRIENDS);
     xmlXPathFreeObject(Obj);
 
-
     g_debug("db_get_profile: END");
+
     return db_resp;
 }
 
