@@ -26,7 +26,7 @@
 #include <glib/gprintf.h>
 #include <glib.h>
 
-#include <mysocials_driver.h>
+#include "../drivers/mysocials_driver.h"
 
 #include "ui_general.h"
 #include "ui_strings.h"
